==> igniteui-react-charts-16.6.8.tgz: package/ES5/FinancialLegendViewManager.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { LegendBaseViewManager } from "./LegendBaseViewManager";
import { markType } from "igniteui-react-core/ES5/type";
/**
 * @hidden
 */
var FinancialLegendViewManager = /** @class */ (function (_super) {
    tslib_1.__extends(FinancialLegendViewManager, _super);
    function FinancialLegendViewManager(a) {
        return _super.call(this, a) || this;
    }
    FinancialLegendViewManager.prototype.j = function () {
        if (this.h == null) {
            return null;
        }
        var a = this.h.createElement("div");
        return a;
    };
    FinancialLegendViewManager.prototype.i = function () {
        if (this.h == null) {
            return null;
        }
        var a = this.h.createElement("span");
        a.setStyleProperty("display", "inline-block");
        a.setStyleProperty("background-color", "#eee");
        a.setStyleProperty("padding", "5px 2px 5px 2px");
        a.setStyleProperty("margin", "2px");
        return a;
    };
    FinancialLegendViewManager.$t = markType(FinancialLegendViewManager, 'FinancialLegendViewManager', LegendBaseViewManager.$);
    return FinancialLegendViewManager;
}(LegendBaseViewManager));
export { FinancialLegendViewManager };

==> igniteui-react-charts-16.11.1.tgz: package/ES5/FinancialLegendViewManager.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { LegendBaseViewManager } from "./LegendBaseViewManager";
import { markType } from "igniteui-react-core/ES5/type";
/**
 * @hidden
 */
var FinancialLegendViewManager = /** @class */ (function (_super) {
    tslib_1.__extends(FinancialLegendViewManager, _super);
    function FinancialLegendViewManager(a) {
        return _super.call(this, a) || this;
    }
    FinancialLegendViewManager.prototype.i = function () {
        if (this.g == null) {
            return null;
        }
        var a = this.g.createElement("div");
        return a;
    };
    FinancialLegendViewManager.prototype.h = function () {
        if (this.g == null) {
            return null;
        }
        var a = this.g.createElement("span");
        a.setStyleProperty("display", "inline-block");
        a.setStyleProperty("padding", "5px 2px 5px 2px");
        a.setStyleProperty("margin", "2px");
        return a;
    };
    FinancialLegendViewManager.$t = markType(FinancialLegendViewManager, 'FinancialLegendViewManager', LegendBaseViewManager.$);
    return FinancialLegendViewManager;
}(LegendBaseViewManager));
export { FinancialLegendViewManager };
